@@ -9,7 +9,11 @@ A quick, hacky script to contruct a class hierarchy list from a set of Python fi
 
 import os, re, sys
 from glob import glob
-from types import StringType
+try:
+	from types import StringTypes
+except ImportError: # fallback for Python < 2.2
+	from types import StringType, UnicodeType
+	StringTypes = (StringType, UnicodeType)
 
 
 def EmptyString(klass):
@@ -155,7 +159,7 @@ class ClassList:
 			klass.printList(file=file)
 
 	def printForWeb(self, hierarchic=0, file=sys.stdout):
-		if type(file) is StringType:
+		if type(file) in StringTypes:
 			file = open(file, 'w')
 			close = 1
 		else:
