@@ -9,7 +9,11 @@ A quick, hacky script to contruct a file list from a set of Python files.
 
 import os, sys
 from glob import glob
-from types import StringType
+try:
+	from types import StringTypes
+except ImportError: # fallback for Python < 2.2
+	from types import StringType, UnicodeType
+	StringTypes = (StringType, UnicodeType)
 
 
 class FileList:
@@ -39,7 +43,7 @@ class FileList:
 		self._files.append(name)
 
 	def printList(self, file=sys.stdout):
-		if type(file) is StringType:
+		if type(file) in StringTypes:
 			file = open(file, 'w')
 			close = 1
 		else:
@@ -56,7 +60,7 @@ class FileList:
 			file.close()
 
 	def printForWeb(self, file=sys.stdout):
-		if type(file) is StringType:
+		if type(file) in StringTypes:
 			file = open(file, 'w')
 			close = 1
 		else:
