@@ -46,8 +46,8 @@ Licensed under the Open Software License version 2.1.
 """
 
 __version__ = '0.1'
-__revision__ = "$Revision: 7219 $"
-__date__ = "$Date: 2008-02-09 15:37:39 -0700 (Sat, 09 Feb 2008) $"
+__revision__ = "$Revision: 7981 $"
+__date__ = "$Date: 2009-06-27 18:59:45 +0200 (Sa, 27. Jun 2009) $"
 
 
 import sys, re
@@ -72,31 +72,24 @@ class ToC:
 		if self._title:
 			toc.append('\n<h%d>%s</h%d>' % (mindepth, self._title, mindepth))
 		maxdepth = self._depth
-		depth = mindepth - 1
-		entries = {}
+		curdepth = mindepth - 1
+		level = 0
 		for heading in headings[self._skip:]:
-			if heading._depth < mindepth or heading._depth > maxdepth:
-				continue
-			while depth < heading._depth:
-				toc.append('\n<ul>')
-				depth += 1
-				entries[depth] = 0
-			while depth > heading._depth:
-				if entries[depth]:
-					toc.append('</li>')
-				toc.append('\n</ul>')
-				depth -= 1
-			if entries[depth]:
-				toc.append('</li>')
-			else:
-				entries[depth] = 1
-			toc.append('\n<li>')
-			toc.append(heading.make_entry())
-		while depth >= mindepth:
-			if entries[depth]:
-				toc.append('</li>')
-			toc.append('\n</ul>')
-			depth -= 1
+			depth = heading._depth
+			if depth != curdepth:
+				if not mindepth <= depth <= maxdepth:
+					continue
+				if depth > curdepth:
+					toc.append('\n<ul>')
+					level += 1
+				elif level > 0:
+					toc.append('</li>\n</ul>')
+					level -= 1
+				curdepth = depth
+			toc.append('\n<li>' + heading.make_entry())
+		while level > 0:
+			toc.append('</li>\n</ul>')
+			level -= 1
 		toc.append('\n</div>')
 		return ''.join(toc)
 
