@@ -38,7 +38,7 @@ out whether it is a Python expression or a Python statement.
 * If it is a Python expression:
   - The expression will be evaluated and processed
     recursively as follows:
-    * It if is a dictionary,
+    * If it is a dictionary,
       use the sorted list of items on separate lines.
     * If it is any other iterable,
       use the list of items on separate lines.
@@ -73,8 +73,8 @@ Licensed under the Open Software License version 2.1.
 """
 
 __version__ = '0.1'
-__revision__ = "$Revision: 7626 $"
-__date__ = "$Date: 2008-11-13 14:48:43 -0700 (Thu, 13 Nov 2008) $"
+__revision__ = "$Revision: 8023 $"
+__date__ = "$Date: 2009-07-13 23:15:17 +0200 (Mo, 13. Jul 2009) $"
 
 
 import sys, re
@@ -88,12 +88,14 @@ class PyTP:
 	"""A very simple Python Template Processor.
 
 	Provides only one method process().
+
 	"""
 
 	def __init__(self, tags=None):
 		"""Initialize the Python template processor.
 
 		You may define your own start and end tags here.
+
 		"""
 		if tags is None:
 			tags = ('<%', '%>')
@@ -172,7 +174,7 @@ class PyTP:
 		"""Output a Python object reasonably as string."""
 		output = []
 		if hasattr(something, 'items'):
-			items = something.items
+			items = something.items()
 			try:
 				items.sort()
 			except Exception:
@@ -184,11 +186,6 @@ class PyTP:
 		else:
 			if something is not None:
 				output.append(str(something))
-		while hasattr(something, 'next'):
-			something = something.next
-			if something is None:
-				break
-			output.append(self._output(something))
 		return '\n'.join(output)
 
 	def _errmsg(self, error, line, code):
