@@ -567,7 +567,7 @@ class Klass:
 		pass
 
 	def writeIndexSQLDefsAfterTable(self, wr):
-		""""Return SQL for creating indexes after table.
+		"""Return SQL for creating indexes after table.
 
 		Subclasses should override this or writeIndexSQLDefsInTable,
 		or no indexes will be created.
