@@ -128,7 +128,7 @@ class MiddleObject(object, NamedValueAccess):
 
 			self._mk_initing = False
 			self._mk_inStore = True
-			self._mk_changed = False # setting the values above will have caused this to be set; clear it now.
+			self._mk_changed = False # setting the values above will have caused this to be set; clear it now
 		finally:
 			self._mk_cacheLock.release()
 		return self
