@@ -64,7 +64,7 @@ class UnknownSerialNumInfo:
 	"""
 
 	def updateStmt(self):
-		assert self.sourceObject.serialNum != 0
+		assert self.sourceObject.serialNum() != 0
 		assert self.targetObject.serialNum() != 0
 		sourceKlass = self.sourceObject._mk_klass
 		assert sourceKlass
