@@ -204,7 +204,7 @@ from types import *
 
 from CSVParser import CSVParser
 from CSVJoiner import joinCSVFields
-from Funcs import positive_id
+from Funcs import positiveId
 from MiscUtils import NoDefault, StringTypes, mxDateTime
 
 try: # for Python < 2.3
@@ -295,7 +295,7 @@ class TableColumn:
 
 	def __repr__(self):
 		return '<%s %r with %r at %x>' % (
-			self.__class__.__name__, self._name, self._type, positive_id(self))
+			self.__class__.__name__, self._name, self._type, positiveId(self))
 
 	def __str__(self):
 		return self._name
