@@ -93,14 +93,14 @@ class PSPContext:
 class PSPCLContext(PSPContext):
 	"""A context for command line compilation.
 
-	Currently used for both cammand line and PSPServletEngine compilation.
+	Currently used for both command line and PSPServletEngine compilation.
 	This class provides all the information necessary during the parsing
 	and page generation steps of the PSP compilation process.
 
 	"""
 
 	def __init__(self, pspfile, trans=None):
-		# self._transactrion = trans # I don't think I need this
+		# self._transaction = trans # I don't think I need this
 		self._baseUri, self._pspfile = os.path.split(pspfile)
 		self._fullpath = pspfile
 		self._pyFileEncoding = None
@@ -120,15 +120,13 @@ class PSPCLContext(PSPContext):
 		"""Provide directory to dump PSP source file to.
 
 		I am probably doing this in reverse order at the moment.
-		I should start with this and get the python filename from it.
+		I should start with this and get the Python filename from it.
 
 		"""
 		return os.path.split(self._pyFileName)[0]
 
 	def getServletClassName(self):
-		"""Return the class name of the servlet being generated.
-
-		"""
+		"""Return the class name of the servlet being generated."""
 		return self._className
 
 	def getFullClassName(self):
@@ -171,7 +169,7 @@ class PSPCLContext(PSPContext):
 		"""Set the encoding of the .py file to generate."""
 		self._pyFileEncoding = encoding
 
-	def setClassName(self , name):
+	def setClassName(self, name):
 		"""Set the class name to create."""
 		self._className = name
 
