@@ -30,7 +30,7 @@ class PSPExamplePage(ExamplePage):
 		viewPath = self.request().uriWebKitRoot() + "PSP/Examples/View"
 		self.menuItem(
 			'View source of<br/>%s' % self.title(),
-			self.request().uriWebKitRoot() + 'PSP/Examples/View?filename=%s' \
+			self.request().uriWebKitRoot() + 'PSP/Examples/View?filename=%s'
 				% os.path.basename(self.request().serverSidePath()))
 		if self.application().hasContext('Documentation'):
 			filename = 'Documentation/WebKit.html'
