@@ -43,12 +43,12 @@ class PSPParser:
 	The PSPParser class does the actual sniffing through the input file
 	looking for anything we're interested in. Basically, it starts by
 	looking at the code looking for a '<' symbol. It looks at the code by
-	working with a PSPReader object, which handle the current location in
+	working with a PSPReader object, which handles the current location in
 	the code. When it finds one, it calls a list of functions, the xxxChecks,
 	asking each if it recognizes the characters as its kind of input.
 	When the check functions look at the characters, if they want it,
 	they go ahead and gobble it up and set up to create it in the servlet
-	when the time comes.  When they return, they return true if they accept
+	when the time comes. When they return, they return true if they accept
 	the character, and the PSPReader object cursor is positioned past the
 	end of the block that the check function accepted.
 
@@ -62,7 +62,7 @@ class PSPParser:
 		self._handler = None
 		self.cout = StringIO() # This is where we dump straight HTML code that none of the checks want
 		self.tmplStart = 0 # marks the start of HTML code
-		self.tmplStop = 0 #marks the end of HTML code
+		self.tmplStop = 0 # marks the end of HTML code
 		self.currentFile = self._reader.Mark().getFile()
 
 	def setEventHandler(self, handler):
@@ -97,7 +97,7 @@ class PSPParser:
 	checklist.append(commentCheck) # add this checker to the list that the parse function will call
 
 	def checkExpression(self, handler, reader):
-		"""Look for "expressions" and handle them"""
+		"""Look for "expressions" and handle them."""
 		OPEN_EXPR = '<%='
 		CLOSE_EXPR = '%>'
 		end_open = None
@@ -188,7 +188,7 @@ class PSPParser:
 					reader.Advance(len(CLOSE_SCRIPT2))
 					handler.setTemplateInfo(self.tmplStart, self.tmplStop)
 					handler.handleEndBlock()
-					print ">>>>Putting a $ at the end of an end tag does nothing, I Say"
+					print 'INFO: Putting a $ at the end of an end tag does nothing.'
 					return 1
 		# that wasn't it
 		reader.reset(start)
@@ -206,7 +206,7 @@ class PSPParser:
 			return 0
 		open = OPEN_SCRIPT
 		close = CLOSE_SCRIPT
-		validAttributes = ('name', 'params')
+		# validAttributes = ('name', 'params')
 		reader.Advance(len(open)) # matches advances it
 		if end_open is not None:
 			attrs = reader.parseTagAttributes()
@@ -215,13 +215,13 @@ class PSPParser:
 				raise PSPParserException, 'Script not terminated'
 			reader.Advance(len(end_open))
 			reader.skipSpaces()
-			PSPUtils.checkAttributes('Script', attrs, validAttributes)
+			# PSPUtils.checkAttributes('Script', attrs, validAttributes)
 		# reader.skipSpaces() # don't skip as spaces may be significant, leave this for the generator
 		start = reader.Mark()
 		try:
 			stop = reader.skipUntil(close)
 		except EOFError:
-			raise EOFError("Reached EOF while looking for ending script tag")
+			raise EOFError('Reached EOF while looking for ending script tag')
 		if stop is None:
 			raise PSPParserException, 'Script not terminated'
 		handler.setTemplateInfo(self.tmplStart, self.tmplStop)
@@ -253,7 +253,7 @@ class PSPParser:
 				if stop is None:
 					raise PSPParserException, 'Script not terminated in %s block' % OPEN_SCRIPT
 			except EOFError:
-				raise EOFError("Reached EOF while looking for ending script tag (%s)" % CLOSE_SCRIPT)
+				raise EOFError('Reached EOF while looking for ending script tag (%s)' % CLOSE_SCRIPT)
 			handler.setTemplateInfo(self.tmplStart, self.tmplStop)
 			handler.handleScriptFile(start, stop, attrs)
 			return 1
@@ -283,7 +283,7 @@ class PSPParser:
 				if stop is None:
 					raise PSPParserException, 'Script not terminated in %s block' % OPEN_SCRIPT
 			except EOFError:
-				raise EOFError("Reached EOF while looking for ending script tag (%s)" % CLOSE_SCRIPT)
+				raise EOFError('Reached EOF while looking for ending script tag (%s)' % CLOSE_SCRIPT)
 			handler.setTemplateInfo(self.tmplStart, self.tmplStop)
 			handler.handleScriptClass(start, stop, attrs)
 			return 1
@@ -296,7 +296,7 @@ class PSPParser:
 
 		I only support one format for these,
 		<psp:method name="xxx" params="xxx,xxx">
-		Then the function BODY, then <psp:method>.
+		Then the function BODY, then </psp:method>.
 
 		"""
 		OPEN_METHOD = '<psp:method'
@@ -329,11 +329,11 @@ class PSPParser:
 	def checkInclude(self, handler, reader):
 		"""Check for inserting another pages output in this spot."""
 		OPEN_INCLUDE = '<psp:include'
-		# CLOSE_INCLUDE_NO_BODY = "/>"
-		CLOSE_INCLUDE_BODY = ">"
-		# CLOSE_INCLUDE = "</psp:include>"
-		# OPEN_INDIVIDUAL_PARAM = "<psp:param"
-		# CLOSE_INDIVIDUAL_PARAM = "/>"
+		# CLOSE_INCLUDE_NO_BODY = '/>'
+		CLOSE_INCLUDE_BODY = '>'
+		# CLOSE_INCLUDE = '</psp:include>'
+		# OPEN_INDIVIDUAL_PARAM = '<psp:param'
+		# CLOSE_INDIVIDUAL_PARAM = '/>'
 		if reader.Matches(OPEN_INCLUDE):
 			param = {}
 			reader.Advance(len(OPEN_INCLUDE))
@@ -360,11 +360,11 @@ class PSPParser:
 
 		"""
 		OPEN_INSERT = '<psp:insert'
-		# CLOSE_INSERT_NO_BODY = "/>"
-		CLOSE_INSERT_BODY = ">"
-		# CLOSE_INSERT = "</psp:insert>"
-		# OPEN_INDIVIDUAL_PARAM = "<psp:param"
-		# CLOSE_INDIVIDUAL_PARAM = "/>"
+		# CLOSE_INSERT_NO_BODY = '/>'
+		CLOSE_INSERT_BODY = '>'
+		# CLOSE_INSERT = '</psp:insert>'
+		# OPEN_INDIVIDUAL_PARAM = '<psp:param'
+		# CLOSE_INDIVIDUAL_PARAM = '/>'
 		if reader.Matches(OPEN_INSERT):
 			param = {}
 			reader.Advance(len(OPEN_INSERT))
@@ -397,8 +397,8 @@ class PSPParser:
 				self.flushCharData(self.tmplStart, self.tmplStop)
 				self.currentFile = reader.Mark().getFile()
 				self.tmplStart = reader.Mark()
-		# in JSP, this is an array of valid tag type to check for,
-		# I'm not using it now, # and I don't think JSP does either
+			# In JSP, this is an array of valid tag type to check for,
+			# I'm not using it now, and I don't think JSP does either
 			if accept:
 				pass
 			accepted = 0
@@ -414,4 +414,4 @@ class PSPParser:
 				st = reader.nextContent() # skip till the next possible tag
 				self.tmplStop = reader.Mark() # mark the end of HTML data
 				self.cout.write(st) # write out the raw HTML data
-			self.flushCharData(self.tmplStart, self.tmplStop) #dump remaining raw HTML
+			self.flushCharData(self.tmplStart, self.tmplStop) # dump remaining raw HTML
