@@ -36,18 +36,18 @@ class ParseEventHandler:
 
 	It implements the handling of all the parsing elements.
 	Note: This files JSP cousin is called ParseEventListener,
-	I don\'t know why, but Handler seemed more appropriate to me.
+	I don't know why, but Handler seemed more appropriate to me.
 
 	"""
 
 	aspace = ' '
 	defaults = {
-		'BASE_CLASS':' WebKit.Page',
+		'BASE_CLASS': 'WebKit.Page',
 		'BASE_METHOD': 'writeHTML',
 		'imports': {'filename': 'classes'},
 		'threadSafe': 'no',
 		'instanceSafe': 'yes',
-		'indent': int(4),
+		'indent': 4,
 		'gobbleWhitespace': 1,
 		'formatter': 'str'
 	}
@@ -86,7 +86,7 @@ class ParseEventHandler:
 	def handleComment(self, start, stop):
 		"""Comments get swallowed into nothing."""
 		self._parser.flushCharData(self.tmplStart, self.tmplStop)
-		return #just eats the comment
+		return # just eats the comment
 
 	def handleInclude(self, attrs, param):
 		"""This is for includes of the form <psp:include ...>
@@ -111,14 +111,14 @@ class ParseEventHandler:
 
 	def importHandler(self, imports, start, stop):
 		importlist = imports.split(',')
-		for i in importlist:
-			if i.find(':') != -1:
-				module, symbol = i.split(':')[:2]
+		for imp in importlist:
+			if imp.find(':') != -1:
+				module, symbol = imp.split(':', 1)
 				self._importedSymbols.append(symbol.strip())
 				implist = "from " + module + " import " + symbol
 				self._imports.append(implist)
 			else:
-				self._imports.append('import ' + i.strip())
+				self._imports.append('import ' + imp.strip())
 
 	def extendsHandler(self, bc, start, stop):
 		"""Extends is a page directive.
