@@ -9,7 +9,7 @@ from ServletWriter import ServletWriter
 
 def PSPCompile(*args):
 	pspfilename = args[0]
-	fil, ext= os.path.basename(pspfilename).split('.')
+	fil, ext = os.path.splitext(os.path.basename(pspfilename))
 	classname = fil + '_' + ext
 	pythonfilename = classname + '.py'
 	context = PSPCLContext(pspfilename)
