@@ -1,4 +1,4 @@
-from MiscUtils.Funcs import positive_id
+from MiscUtils.Funcs import positiveId
 
 
 class Role:
@@ -47,7 +47,7 @@ class Role:
 
 	def __repr__(self):
 		return '<%s %r instance at %x>' % (
-			self.__class__, self._name, positive_id(self))
+			self.__class__, self._name, positiveId(self))
 
 
 	## The big question ##
