@@ -141,7 +141,7 @@ class Application(ConfigurableForServerSidePath, Object):
 
 	## Init ##
 
-	def __init__(self, server, useSessionSweeper=1):
+	def __init__(self, server, useSessionSweeper=True):
 		"""Called only by `AppServer`, sets up the Application."""
 
 		self._server = server
@@ -333,7 +333,7 @@ class Application(ConfigurableForServerSidePath, Object):
 			shutDownHandler()
 		del self._shutDownHandlers
 
-		print "Application has been succesfully shutdown."
+		print "Application has been successfully shutdown."
 
 	def addShutDownHandler(self, func):
 		"""Add a shutdown handler.
@@ -888,7 +888,8 @@ class Application(ConfigurableForServerSidePath, Object):
 
 		"""
 		request = trans.request()
-		editlink = request.adapterName() + "/Admin/EditFile"
+		editlink = (self.setting('IncludeEditLink')
+			and request.adapterName() + "/Admin/EditFile" or None)
 		self._exceptionHandlerClass(self, trans, excInfo,
 			{"editlink": editlink})
 
@@ -1001,8 +1002,8 @@ class Application(ConfigurableForServerSidePath, Object):
 			request.pathInfo(), request.extraURLPath() or '',
 			request.queryString() and '?' + request.queryString() or '')
 		if self.setting('Debug')['Sessions']:
-			print '>> [sessions] handling UseAutomaticPathSessions, ' \
-				'redirecting to', url
+			print ">> [sessions] handling UseAutomaticPathSessions, " \
+				"redirecting to", url
 		trans.response().sendRedirect(url)
 		raise EndResponse
 
@@ -1020,7 +1021,7 @@ class Application(ConfigurableForServerSidePath, Object):
 			request.pathInfo(), request.extraURLPath() or '',
 			request.queryString() and '?' + request.queryString() or '')
 		if self.setting('Debug')['Sessions']:
-			print ">> [sessions] handling unnecessary path session, ' \
-				'redirecting to", url
+			print ">> [sessions] handling unnecessary path session, " \
+				"redirecting to", url
 		trans.response().sendRedirect(url)
 		raise EndResponse
