@@ -1,6 +1,6 @@
 from Common import *
 
-from MiscUtils.Funcs import positive_id
+from MiscUtils.Funcs import positiveId
 
 # If this is Python 2.2 or greater, import the standard Cookie module
 # as CookieEngine. Otherwise, import WebUtils.Cookie as CookieEngine.
@@ -18,7 +18,7 @@ if pyVer and pyVer[:2] >= (2, 2):
 	path = []
 	thisDir = os.path.abspath(os.path.dirname(__file__))
 	for dir in sys.path:
-		if not dir or dir == '.':
+		if not dir or dir == os.curdir:
 			continue
 		if os.path.abspath(dir) == thisDir:
 			continue
@@ -91,7 +91,7 @@ class Cookie(Object):
 	def __repr__(self):
 		return ('%s(id=0x%x, name=%r, domain=%r, '
 				'path=%r, value=%r, expires=%r, maxAge=%r)'
-			% (self.__class__.__name__, positive_id(self),
+			% (self.__class__.__name__, positiveId(self),
 				self.name(), self.domain(),
 				self.path(), self.value(), self.expires(), self.maxAge()))
 
