@@ -11,34 +11,22 @@ class RequestInformation(ExamplePage):
 		self.writeln('<table style="font-size:small;width:100%"'
 			' border="0" cellpadding="2" cellspacing="2" width="100%">')
 		request = self.request()
-		self.dict('fields()', request.fields())
-		self.dict('environ()', request.environ())
-		self.dict('cookies()', request.cookies())
+		self.showDict('fields()', request.fields())
+		self.showDict('environ()', request.environ())
+		self.showDict('cookies()', request.cookies())
 		self.writeln('</table>')
 		setCookie = self.response().setCookie
 		setCookie('TestCookieName', 'CookieValue')
 		setCookie('TestExpire1', 'expires in 1 minute', expires='+1m')
 
-	def pair(self, key, value):
-		valueType = type(value)
-		if valueType is type([]) or valueType is type(()):
-			value = ', '.join(map(str, value))
-		self.writeln('<tr valign="top"><td>%s</td><td>%s</td></tr>'
-			% (key, self.htmlEncode(str(value))))
-
-	def list(self, codeString):
-		list = eval(codeString)
-		assert type(list) is type([])  or  type(list) is type(())
-		self.pair(codeString, list)
-
-	def dict(self, name, dict):
+	def showDict(self, name, d):
 		self.writeln('<tr valign="top">'
 			'<td style="background-color:#CCF" colspan="2">%s</td>'
 			'</tr>' % (name))
-		keys = dict.keys()
+		keys = d.keys()
 		keys.sort()
-		for name in keys:
+		for key in keys:
 			self.writeln('<tr valign="top" style="background-color:#EEF">'
-				'<td>%s</td><td>%s</td></tr>' % (name, self.htmlEncode(
-				str(dict[name])).replace('\n', '<br>').replace(
+				'<td>%s</td><td>%s</td></tr>' % (key, self.htmlEncode(
+				str(d[key])).replace('\n', '<br>').replace(
 				',', ',<wbr>').replace(';', ';<wbr>').replace(':/', ':<wbr>/')))
