@@ -60,6 +60,7 @@ class HTTPContent(HTTPServlet):
 
 		Invoked in response to a GET request method. All methods
 		are passed to `_respond`.
+
 		"""
 		self._respond(transaction)
 
@@ -123,7 +124,7 @@ class HTTPContent(HTTPServlet):
 
 		"""
 		self._session = None
-		self._request  = None
+		self._request = None
 		self._response = None
 		self._transaction = None
 		HTTPServlet.sleep(self, transaction)
@@ -190,9 +191,10 @@ class HTTPContent(HTTPServlet):
 	def canBeThreaded(self):
 		"""Declares whether servlet can be threaded.
 
-		Returns 0 because of the instance variables we set up in `awake`.
+		Returns False because of the instance variables we set up in `awake`.
+
 		"""
-		return 0
+		return False
 
 
 	## Actions ##
