@@ -2,9 +2,10 @@ from types import FloatType, IntType, LongType, StringType, TupleType
 
 from Common import *
 
-# time.gmtime() no longer returns a tuple, and there is no globally defined
-# type for this at the moment.
-TimeTupleType = type(time.gmtime(0))
+try:
+    TimeTupleType = time.struct_time
+except AttributeError: # Python < 2.2
+    TimeTupleType = type(time.gmtime(0))
 
 from Response import Response
 from Cookie import Cookie
@@ -135,7 +136,7 @@ class HTTPResponse(Response):
 			elif t == 'NEVER':
 				t = time.gmtime(time.time())
 				t = (t[0] + 10,) + t[1:]
-			elif t[0] == '+':
+			elif t.startswith('+'):
 				t = time.time() + timeDecode(t[1:])
 		if t:
 			if type(t) in (IntType, LongType, FloatType):
@@ -446,7 +447,7 @@ class HTTPResponse(Response):
 
 		"""
 		linesep = "\n"
-		lines = headerstr.split("\n")
+		lines = headerstr.split(linesep)
 		for line in lines:
 			sep = line.find(":")
 			if sep:
