@@ -1,10 +1,11 @@
 import time
+
 from WebKit.SidebarPage import SidebarPage
 
 
 class TestIMS(SidebarPage):
 
-	def cornerTitle(Self):
+	def cornerTitle(self):
 		return 'Testing'
 
 	def error(self, msg):
@@ -26,7 +27,7 @@ class TestIMS(SidebarPage):
 		sd = self.request().serverDictionary()
 		self._host = sd['HTTP_HOST'] # includes the port
 		self._httpconnection = sd.get('HTTPS', '').lower() == 'on' \
-			and  httplib.HTTPSConnection or httplib.HTTPConnection
+			and httplib.HTTPSConnection or httplib.HTTPConnection
 		servletPath = self.request().servletPath()
 		self.write('<h2>Test If-Modified-Since support in Webware</h2>')
 		# pick a static file which is served up by Webwares UnknownFileHandler
