@@ -1,9 +1,9 @@
-"""
-FixPath.py
+"""FixPath.py
 
 Enhance sys.path so that we're guaranteed to import the MiddleKit that
 we reside in. This is particularly important for Webware developers
 that might have more than one Webware source tree on their file system.
+
 """
 
 
@@ -19,4 +19,5 @@ if sys.path and sys.path[0] == '':
 else:
 	index = 0
 sys.path.insert(index, os.path.abspath('../..'))
+
 import WebKit
