@@ -1,4 +1,5 @@
 #!/usr/bin/env python
+
 """stress.py
 
 By Chuck Esterbrook
@@ -35,7 +36,7 @@ the fact that they will contain stale session ids.
 """
 
 
-import sys, os, time, socket
+import sys, os, socket
 from glob import glob
 from marshal import dumps
 from random import randint
@@ -44,7 +45,7 @@ from threading import Thread
 
 
 def usage():
-	""" Prints usage of this program and exits. """
+	"""Print usage of this program and exit."""
 	sys.stdout = sys.stderr
 	name = sys.argv[0]
 	print '%s usage:' % name
