@@ -35,6 +35,29 @@ try:
 except (TypeError, AttributeError):
 	PyThreadState_SetAsyncExc = None
 
+try:
+	import fcntl
+except ImportError: # not Unix
+	fcntl = None
+else:
+	try:
+		F_GETFD, F_SETFD = fcntl.F_SETFD, fcntl.F_SETFD
+	except AttributeError: # Python < 2.2
+		try:
+			import FCNTL
+			F_GETFD, F_SETFD = FCNTL.F_SETFD, FCNTL.F_SETFD
+		except (ImportError, AttributeError):
+			fcntl = None
+	if fcntl:
+		try:
+			FD_CLOEXEC = fcntl.FD_CLOEXEC
+		except AttributeError: # Python < 2.2.1 or not defined
+			try:
+				import FCNTL
+				FD_CLOEXEC = FCNTL.FD_CLOEXEC
+			except (ImportError, AttributeError):
+				FD_CLOEXEC = 1
+
 from Common import *
 import AppServer as AppServerModule
 from PidFile import ProcessRunning
@@ -58,6 +81,7 @@ defaultConfig = {
 	'StartServerThreads': 10, # initial number of server threads
 	'MinServerThreads': 5, # minimum number
 	'MaxServerThreads': 20, # maxium number
+	'UseDaemonThreads': True, # use daemonic worker threads
 	'MaxRequestTime': 300, # maximum request execution time in seconds
 	'RequestQueueSize': 0, # means twice the maximum number of threads
 	'RequestBufferSize': 8*1024, # 8 kBytes
@@ -159,6 +183,14 @@ class WorkerThread(Thread):
 		return ret
 
 
+def setCloseOnExecFlag(fd):
+	"""Set flag for file descriptor not to be inherited by child processes."""
+	try:
+		fcntl.fcntl(fd, F_SETFD, fcntl.fcntl(fd, F_GETFD) | FD_CLOEXEC)
+	except IOError:
+		pass
+
+
 class ThreadedAppServer(AppServer):
 	"""Threaded Application Server.
 
@@ -202,6 +234,7 @@ class ThreadedAppServer(AppServer):
 			threadCount = self.setting('StartServerThreads')
 			self._maxServerThreads = self.setting('MaxServerThreads')
 			self._minServerThreads = self.setting('MinServerThreads')
+			self._useDaemonThreads = self.setting('UseDaemonThreads')
 			self._requestQueueSize = self.setting('RequestQueueSize')
 			if not self._requestQueueSize:
 				# if not set, make queue size twice the max number of threads
@@ -271,6 +304,8 @@ class ThreadedAppServer(AppServer):
 		try:
 			sock.bind(serverAddress)
 			sock.listen(1024)
+			if fcntl:
+				setCloseOnExecFlag(sock.fileno())
 		except Exception:
 			print "Error: Can not listen for %s on %s" % (
 				handlerClass.settingPrefix, str(serverAddress))
@@ -288,7 +323,7 @@ class ThreadedAppServer(AppServer):
 			print "Warning: %s already exists" % adrFile
 			try:
 				os.unlink(adrFile)
-			except OSError: # we cannot remove the file
+			except (AttributeError, OSError): # we cannot remove the file
 				if open(adrFile).read() == adrStr:
 					return # same content, so never mind
 				else:
@@ -498,6 +533,8 @@ class ThreadedAppServer(AppServer):
 			print "Spawning new thread"
 		t = WorkerThread(target=self.threadloop)
 		t._processing = False
+		if self._useDaemonThreads:
+			t.setDaemon(True)
 		t.start()
 		self._threadPool.append(t)
 		self._threadCount += 1
@@ -721,19 +758,54 @@ class ThreadedAppServer(AppServer):
 				if os.path.exists(adrFile):
 					try:
 						os.unlink(adrFile)
-					except OSError:
+					except (AttributeError, OSError):
 						print "Warning: Could not remove", adrFile
 		# Tell all threads to end:
 		for i in range(self._threadCount):
 			self._requestQueue.put(None)
-		if self._canAbortRequest:
-			for t in self._threadHandler.keys():
-				t.abort(ServerShutDownError)
+		# Join all threads:
+		closeTime = time.time() + 3
 		for t in self._threadPool:
+			timeout = max(0.1, closeTime - time.time())
 			try:
-				t.join()
+				t.join(timeout)
 			except Exception:
 				pass
+		# Check whether all threads have ended:
+		for t in self._threadPool:
+			if t.isAlive():
+				if debug:
+					print "Hanging worker thread", t.threadID()
+				running = True
+				break
+		else:
+			running = False
+		if running and self._canAbortRequest:
+			# Abort all remaining threads:
+			print "Aborting hanging worker threads..."
+			for t in self._threadPool:
+				if t.isAlive():
+					t.abort(ServerShutDownError)
+			# Join remaining threads:
+			closeTime = time.time() + 3
+			for t in self._threadPool:
+				if t.isAlive():
+					timeout = max(0.1, closeTime - time.time())
+					try:
+						t.join(timeout)
+					except Exception:
+						pass
+			# Check whether remaining threads have ended:
+			for t in self._threadPool:
+				if t.isAlive():
+					if debug:
+						print "Warning: Could not abort thread", t.threadID()
+					else:
+						print "Warning: Could not abort all worker threads"
+					break
+			else:
+				print "Hanging worker threads have been aborted."
+				running = False
 		# Call super's shutdown:
 		AppServer.shutDown(self)
 
@@ -979,7 +1051,7 @@ class MonitorHandler(Handler):
 		if not requestDict:
 			return
 
-		requestDict['environ'] = { 'REQUEST_URI': '*%s %s*'
+		requestDict['environ'] = {'REQUEST_URI': '*%s %s*'
 			% (self.settingPrefix, requestDict['format'])}
 		self.startRequest(requestDict)
 
@@ -1181,7 +1253,7 @@ See the Troubleshooting section of the WebKit Install Guide.\r''')
 				environ[items[i]] = items[i+1]
 		except IndexError:
 			raise ProtocolError, 'Malformed SCGI headers'
-		return { 'format': 'CGI', 'time': time.time(), 'environ': environ }
+		return {'format': 'CGI', 'time': time.time(), 'environ': environ}
 
 
 # Determines whether the main look should run in another thread.
@@ -1322,34 +1394,37 @@ def shutDown(signum, frame):
 		print "No running app server was found."
 
 try:
+	currentFrames = sys._current_frames
+except AttributeError: # Python < 2.5
 	# Use the threadframe module for dumping thread stack frames:
 	# http://www.majid.info/mylos/stories/2004/06/10/threadframe.html
-	import threadframe
+	try:
+		import threadframe
+	except ImportError: # threadframe module not installed
+		currentFrames = None
+	else:
+		currentFrames = threadframe.dict
 
-	def threadDump(signum, frame):
-		"""Signal handler for dumping thread stack frames to stdout."""
-		print
-		print "App server has been signaled to attempt a thread dump."
-		print
-		print "Thread stack frame dump at", asclocaltime()
-		sys.stdout.flush()
-		frames = threadframe.dict()
-		items = frames.items()
-		items.sort()
-		print
-		print "-" * 79
-		print
-		for threadID, frame in items:
-			print "Thread ID: %d (reference count = %d)" % (
-				threadID, sys.getrefcount(frame))
-			print ''.join(traceback.format_list(traceback.extract_stack(frame)))
-		items.sort()
-		print "-" * 79
-		sys.stdout.flush()
-
-except ImportError:
-	# threadframe module not available
-	threadDump = None
+def threadDump(signum, frame):
+	"""Signal handler for dumping thread stack frames to stdout."""
+	print
+	print "App server has been signaled to attempt a thread dump."
+	print
+	print "Thread stack frame dump at", asclocaltime()
+	sys.stdout.flush()
+	frames = currentFrames()
+	threadIDs = frames.keys()
+	threadIDs.sort()
+	print
+	print "-" * 79
+	print
+	for threadID in threadIDs:
+		frame = frames[threadID]
+		print "Thread ID: %d (reference count = %d)" % (
+			threadID, sys.getrefcount(frame))
+		print ''.join(traceback.format_list(traceback.extract_stack(frame)))
+	print "-" * 79
+	sys.stdout.flush()
 
 import signal
 
@@ -1372,7 +1447,7 @@ try:
 except AttributeError:
 	SIGINT = None
 
-if threadDump:
+if currentFrames:
 
 	# Signals for creating a thread dump
 
@@ -1388,6 +1463,7 @@ if threadDump:
 	except AttributeError:
 		SIGBREAK = None
 
+# Command line interface
 
 import re
 settingRE = re.compile(r'^(?:--)?([a-zA-Z][a-zA-Z0-9]*\.[a-zA-Z][a-zA-Z0-9]*)=')
@@ -1405,20 +1481,20 @@ def main(args):
 	function = run
 	daemon = False
 	workDir = None
-	for a in args[:]:
-		if settingRE.match(a):
-			match = settingRE.match(a)
+	for arg in args:
+		if settingRE.match(arg):
+			match = settingRE.match(arg)
 			name = match.group(1)
-			value = a[match.end():]
+			value = arg[match.end():]
 			Configurable.addCommandLineSetting(name, value)
-		elif a == "stop":
+		elif arg == "stop":
 			function = AppServerModule.stop
-		elif a == "daemon":
+		elif arg == "daemon":
 			daemon = True
-		elif a == "start":
+		elif arg == "start":
 			pass
-		elif a[:8] == "workdir=":
-			workDir = a[8:]
+		elif arg[:8] == "workdir=":
+			workDir = arg[8:]
 		else:
 			print usage
 			return
