@@ -384,11 +384,12 @@ class _FileParser(URLParser):
 			if result is not None:
 				return result
 
-			assert not requestPath or requestPath.startswith('/'), \
-				"Not what I expected: %s" % repr(requestPath)
 			if not requestPath or requestPath == '/':
 				return self.parseIndex(trans, requestPath)
 
+			if not requestPath.startswith('/'):
+				raise HTTPNotFound("Invalid path info: %s" % requestPath)
+
 			parts = requestPath[1:].split('/', 1)
 			nextPart = parts[0]
 			restPart = len(parts) > 1 and '/' + parts[1] or ''
@@ -415,8 +416,8 @@ class _FileParser(URLParser):
 
 			req._extraURLPath = restPart
 
-		if not self._extraPathInfo and req._extraURLPath:
-			raise HTTPNotFound("Invalid extra path info: %s")
+		if not self._extraPathInfo and restPart:
+			raise HTTPNotFound("Invalid extra path info: %s" % restPart)
 
 		req._serverSidePath = name
 
