@@ -335,7 +335,7 @@ class Installer:
 		open(targetName, 'w').write(result)
 
 	def createPySummary(self, filename, dir):
-		"""Create a HTML module summary."""
+		"""Create an HTML module summary."""
 		from DocSupport.PySummary import PySummary
 		module = os.path.splitext(os.path.basename(filename))[0]
 		targetName = '%s/%s.html' % (dir, module)
@@ -347,7 +347,7 @@ class Installer:
 		open(targetName, 'w').write(html)
 
 	def createPyDocs(self, filename, dir):
-		"""Create a HTML module documentation using pydoc."""
+		"""Create an HTML module documentation using pydoc."""
 		try:
 			import pydoc
 		except ImportError:
@@ -377,7 +377,7 @@ class Installer:
 			self.printMsg(msg)
 
 	def createFileList(self, filesDir, docsDir):
-		"""Create a HTML list of the source files."""
+		"""Create an HTML list of the source files."""
 		from DocSupport.FileList import FileList
 		name = filesDir.replace('/', '.')
 		self.printMsg('Creating file list of %s...' % name)
@@ -394,7 +394,7 @@ class Installer:
 			os.chdir(saveDir)
 
 	def createClassList(self, filesDir, docsDir):
-		"""Create a HTML class hierarchy listing of the source files."""
+		"""Create an HTML class hierarchy listing of the source files."""
 		from DocSupport.ClassList import ClassList
 		name = filesDir.replace('/', '.')
 		self.printMsg('Creating class list of %s...' % name)
@@ -414,7 +414,7 @@ class Installer:
 			os.chdir(saveDir)
 
 	def createComponentIndex(self):
-		"""Create a HTML component index of Webware itself."""
+		"""Create an HTML component index of Webware itself."""
 		print 'Creating ComponentIndex.html...'
 		ht = ["<% header('Webware Documentation', 'titlebar',"
 			" 'ComponentIndex.css') %>"]
@@ -457,7 +457,7 @@ class Installer:
 		for comp in self._comps:
 			comp['webwareVersion'] = self._props['version']
 			comp['webwareVersionString'] = self._props['versionString']
-			# Create 'htDocs' as a HTML fragment corresponding to comp['docs']
+			# Create 'htDocs' as an HTML fragment corresponding to comp['docs']
 			ht = []
 			for doc in comp['docs']:
 				ht.append(link % (doc['file'], doc['name']))
@@ -510,7 +510,7 @@ class Installer:
 					docsDirs.append(docsDir)
 		for docsDir in docsDirs:
 			initFile = docsDir + '/__init__.py'
-			if not os.path.exists(initFile) or 1:
+			if not os.path.exists(initFile):
 				open(initFile, 'w').write(
 					'# this can be browsed as a Webware context\n')
 		# Copy favicon to the default context
@@ -565,13 +565,13 @@ class Installer:
 			t = 'WebKit/webkit'
 			open(t, 'wb').write(open(s, 'rb').read())
 
-	def compileModules(self, force=0):
+	def compileModules(self, force=1):
 		"""Compile modules in all installed componentes."""
 		from compileall import compile_dir
 		print
 		print 'Byte compiling all modules...'
 		for comp in self._comps:
-			dir = comp['dirname']
+			dir = os.path.abspath(comp['dirname'])
 			try:
 				compile_dir(dir, force=force, quiet=1)
 			except TypeError: # workaround for Python < 2.3
@@ -637,7 +637,7 @@ Installation is finished.''' % ((os.sep,)*2)
 		return template.split('\n<!-- page content -->\n', 1)
 
 	def processHtmlDocFile(self, htmlFile):
-		"""Process a HTML file."""
+		"""Process an HTML file."""
 		txtFile = os.path.splitext(htmlFile)[0] + '.txt'
 		if os.path.exists(txtFile):
 			# A text file with the same name exists:
